@@ -1,6 +1,8 @@
 from cStringIO import StringIO
+
 import datetime
 import gzip
+import logging
 import os
 import sys
 import traceback
@@ -14,11 +16,13 @@ from django.core.urlresolvers import resolve
 from djexceptional.utils import memoize, json_dumps, meta_to_http
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 EXCEPTIONAL_PROTOCOL_VERSION = 6
 EXCEPTIONAL_API_ENDPOINT = "http://api.getexceptional.com/api/errors"
 
+LOG = logging.getLogger('djexceptional')
+
 
 class ExceptionalMiddleware(object):
 
@@ -54,11 +58,14 @@ class ExceptionalMiddleware(object):
         req.headers['Content-Encoding'] = 'gzip'
         req.headers['Content-Type'] = 'application/json'
 
-        conn = urllib2.urlopen(req)
         try:
-            conn.read()
-        finally:
-            conn.close()
+            conn = urllib2.urlopen(req)
+            try:
+                conn.read()
+            finally:
+                conn.close()
+        except Exception, exc:
+            LOG.exception("Error communicating with the Exceptional service: %r", exc)
 
     @staticmethod
     def compress(bytes):
